Method: FlexMock::AtLeastCountValidator#eligible?
- Defined in:
- lib/flexmock/validators.rb
#eligible?(n) ⇒ Boolean
If the expectation has been called n times, is it still eligible to be called again? Since this validator only establishes a lower limit, not an upper limit, then the answer is always true.
113 114 115 |
# File 'lib/flexmock/validators.rb', line 113 def eligible?(n) true end |